@@ -207,20 +207,21 @@ class Lookup(Query):
 
             for kid in self.kids[0]:
                 tokn = await kid.compute(runt, None)
-                for form, _, _ in s_scrape.scrape_types:
-                    regx = s_scrape.regexes.get(form)
-                    if regx.match(tokn):
+                for form, valu in s_scrape.scrape(tokn):
+                    # restrict to only full matches
+                    if valu != tokn:
+                        continue
 
-                        if self.autoadd:
-                            node = await runt.snap.addNode(form, tokn)
+                    if self.autoadd:
+                        node = await runt.snap.addNode(form, tokn)
+                        yield node, runt.initPath(node)
+
+                    else:
+                        norm, info = runt.model.form(form).type.norm(tokn)
+                        node = await runt.snap.getNodeByNdef((form, norm))
+                        if node is not None:
                             yield node, runt.initPath(node)
 
-                        else:
-                            norm, info = runt.model.form(form).type.norm(tokn)
-                            node = await runt.snap.getNodeByNdef((form, norm))
-                            if node is not None:
-                                yield node, runt.initPath(node)
-
         realgenr = lookgenr()
         if len(self.kids) > 1:
             realgenr = self.kids[1].run(runt, realgenr)
@@ -808,6 +809,7 @@ class SetItemOper(Oper):
             valu = await self.kids[2].compute(runt, path)
 
             # TODO: ditch this when storm goes full heavy object
+            name = await tostr(name)
             await item.setitem(name, valu)
 
             yield node, path
@@ -1837,13 +1839,43 @@ class PropPivot(PivotOper):
                 mesg = ': '.join((f'{e.__class__.__qualname__} [{repr(valu)}] during pivot', mesg))
                 await runt.snap.fire('warn', mesg=mesg, **items)
 
-class Cond(AstNode):
+class Value(AstNode):
+    '''
+    The base class for all values and value expressions.
+    '''
+
+    def __init__(self, kids=()):
+        AstNode.__init__(self, kids=kids)
+
+    def __repr__(self):
+        return self.repr()
+
+    def isRuntSafe(self, runt):
+        return all(k.isRuntSafe(runt) for k in self.kids)
+
+    async def compute(self, runt, path): # pragma: no cover
+        raise s_exc.NoSuchImpl(name=f'{self.__class__.__name__}.compute()')
 
     async def getLiftHints(self, runt, path):
         return []
 
-    async def getCondEval(self, runt): # pragma: no cover
-        raise s_exc.NoSuchImpl(name=f'{self.__class__.__name__}.getCondEval()')
+    async def getCondEval(self, runt):
+        '''
+        Return a function that may be used to evaluate the boolean truth
+        of the value expression using a runtime and optional node path.
+        '''
+        async def cond(node, path):
+            return await tobool(await self.compute(runt, path))
+
+        return cond
+
+class Cond(Value):
+    '''
+    A condition that is evaluated to filter nodes.
+    '''
+    # Keeping the distinction of Cond as a subclass of Value
+    # due to the fact that Cond instances may always presume
+    # they are being evaluated per node.
 
 class SubqCond(Cond):
 
@@ -2384,26 +2416,6 @@ class FiltByArray(FiltOper):
     +:foo*[^=visi]
     '''
 
-class Value(AstNode):
-
-    '''
-    A fixed/constant value.
-    '''
-    def __init__(self, kids=()):
-        AstNode.__init__(self, kids=kids)
-
-    #def repr(self):
-        #return f'{self.__class__.__name__}: ds={self.kids}'
-
-    def __repr__(self):
-        return self.repr()
-
-    def isRuntSafe(self, runt):
-        return all(k.isRuntSafe(runt) for k in self.kids)
-
-    async def compute(self, runt, path): # pragma: no cover
-        raise s_exc.NoSuchImpl(name=f'{self.__class__.__name__}.compute()')
-
 class ArgvQuery(Value):
 
     def isRuntSafe(self, runt):
@@ -2516,19 +2528,12 @@ class CallKwarg(CallArgs):
 class CallKwargs(CallArgs):
     pass
 
-class VarValue(Value, Cond):
+class VarValue(Value):
 
     def validate(self, runt):
         if runt.runtvars.get(self.name) is None:
             raise s_exc.NoSuchVar(name=self.name)
 
-    async def getCondEval(self, runt):
-
-        async def cond(node, path):
-            return await self.compute(runt, path)
-
-        return cond
-
     def prepare(self):
         assert isinstance(self.kids[0], Const)
         self.name = self.kids[0].value()
@@ -2554,6 +2559,7 @@ class VarDeref(Value):
     async def compute(self, runt, path):
         base = await self.kids[0].compute(runt, path)
         name = await self.kids[1].compute(runt, path)
+        name = await tostr(name)
         valu = s_stormtypes.fromprim(base, path=path)
         return await valu.deref(name)
 
@@ -2573,20 +2579,13 @@ class FuncCall(Value):
         with s_scope.enter({'runt': runt}):
             return await s_coro.ornot(func, *argv, **kwargs)
 
-class DollarExpr(Value, Cond):
+class DollarExpr(Value):
     '''
     Top level node for $(...) expressions
     '''
     async def compute(self, runt, path):
         return await self.kids[0].compute(runt, path)
 
-    async def getCondEval(self, runt):
-
-        async def cond(node, path):
-            return await self.compute(runt, path)
-
-        return cond
-
 async def expr_add(x, y):
     return await toint(x) + await toint(y)
 async def expr_sub(x, y):
