@@ -101,7 +101,10 @@ class NexsRoot(s_base.Base):
         # just in case were previously configured differently
         logindx = self.nexslog.index()
         hotindx = self.nexshot.get('nexs:indx')
-        self.nexshot.set('nexs:indx', max(logindx, hotindx))
+        maxindx = max(logindx, hotindx)
+
+        self.nexshot.set('nexs:indx', maxindx)
+        self.nexslog.indx = maxindx
 
         async def fini():
 
@@ -203,6 +206,20 @@ class NexsRoot(s_base.Base):
         else:
             return self.nexshot.get('nexs:indx')
 
+    async def setindex(self, indx):
+
+        nexsindx = await self.index()
+        if indx < nexsindx:
+            logger.error(f'setindex ({indx}) is less than current index ({nexsindx})')
+            return False
+
+        if self.donexslog:
+            self.nexslog.indx = indx
+        else:
+            self.nexshot.set('nexs:indx', indx)
+
+        return True
+
     async def _eat(self, item, indx=None):
 
         if self.donexslog:
