@@ -82,6 +82,8 @@ class StormSvc:
     _storm_svc_pkgs = ()  # type: ignore
 
     async def getStormSvcInfo(self):
+        # Users must specify the service name
+        assert self._storm_svc_name != 'noname'
         return {
             'name': self._storm_svc_name,
             'vers': self._storm_svc_vers,
@@ -106,7 +108,8 @@ class StormSvcClient(s_base.Base, s_stormtypes.Proxy):
         self.sdef = sdef
 
         self.iden = sdef.get('iden')
-        self.name = sdef.get('name')
+        self.name = sdef.get('name')  # Local name for the cortex
+        self.svcname = ''  # remote name from the service
 
         # service info from the server...
         self.info = None
@@ -121,11 +124,15 @@ class StormSvcClient(s_base.Base, s_stormtypes.Proxy):
         self.onfini(self.proxy.fini)
 
     async def _runSvcInit(self):
+        # Set the latest reference for this object to the remote svcname
+        self.core.svcsbysvcname.pop(self.svcname, None)
+        self.svcname = self.info['name']
+        self.core.svcsbysvcname[self.svcname] = self
 
         try:
             await self.core._delStormSvcPkgs(self.iden)
 
-        except asyncio.CancelledError:  # pragma: no cover
+        except asyncio.CancelledError:  # pragma: no cover  TODO:  remove once >= py 3.8 only
             raise
 
         except Exception:
@@ -139,7 +146,7 @@ class StormSvcClient(s_base.Base, s_stormtypes.Proxy):
                 pdef['svciden'] = self.iden
                 await self.core._hndladdStormPkg(pdef)
 
-            except asyncio.CancelledError:  # pragma: no cover
+            except asyncio.CancelledError:  # pragma: no cover  TODO:  remove once >= py 3.8 only
                 raise
 
             except Exception:
@@ -152,7 +159,7 @@ class StormSvcClient(s_base.Base, s_stormtypes.Proxy):
             if evts is not None:
                 self.sdef = await self.core.setStormSvcEvents(self.iden, evts)
 
-        except asyncio.CancelledError:  # pragma: no cover
+        except asyncio.CancelledError:  # pragma: no cover  TODO:  remove once >= py 3.8 only
             raise
 
         except Exception:
@@ -162,7 +169,7 @@ class StormSvcClient(s_base.Base, s_stormtypes.Proxy):
             if self.core.isactive:
                 await self.core._runStormSvcAdd(self.iden)
 
-        except asyncio.CancelledError:  # pragma: no cover
+        except asyncio.CancelledError:  # pragma: no cover  TODO:  remove once >= py 3.8 only
             raise
 
         except Exception:
