@@ -1,4 +1,5 @@
 import io
+import asyncio
 import hashlib
 import logging
 import unittest.mock as mock
@@ -10,6 +11,9 @@ import synapse.axon as s_axon
 import synapse.common as s_common
 import synapse.telepath as s_telepath
 
+import synapse.lib.httpapi as s_httpapi
+import synapse.lib.msgpack as s_msgpack
+
 import synapse.tests.utils as s_t_utils
 
 logger = logging.getLogger(__name__)
@@ -170,6 +174,11 @@ class AxonTest(s_t_utils.SynTest):
         self.eq(67108899, info.get('size:bytes'))
         self.eq(6, info.get('file:count'))
 
+        byts = b''.join([s_msgpack.en('foo'), s_msgpack.en('bar'), s_msgpack.en('baz')])
+        size, sha256b = await axon.put(byts)
+        sha256 = s_common.ehex(sha256b)
+        self.eq(('foo', 'bar', 'baz'), [item async for item in axon.iterMpkFile(sha256)])
+
         # When testing a local axon, we want to ensure that the FD was in fact fini'd
         if isinstance(fd, s_axon.UpLoad):
             self.true(fd.fd.closed)
@@ -388,6 +397,14 @@ class AxonTest(s_t_utils.SynTest):
                 resp = await proxy.wget(f'http://visi:secret@127.0.0.1:{port}/api/v1/axon/files/by/sha256/{sha2}')
                 self.false(resp['ok'])
 
+                async def timeout(self):
+                    await asyncio.sleep(2)
+
+                with mock.patch.object(s_httpapi.ActiveV1, 'get', timeout):
+                    resp = await proxy.wget(f'https://visi:secret@127.0.0.1:{port}/api/v1/active', timeout=1)
+                    self.eq(False, resp['ok'])
+                    self.eq('TimeoutError', resp['mesg'])
+
         conf = {'http:proxy': 'socks5://user:pass@127.0.0.1:1'}
         async with self.getTestAxon(conf=conf) as axon:
             async with axon.getLocalProxy() as proxy:
