@@ -1,5 +1,6 @@
 import asyncio
 import datetime
+import unittest.mock as mock
 
 import synapse.exc as s_exc
 import synapse.common as s_common
@@ -190,6 +191,35 @@ class StormTest(s_t_utils.SynTest):
             with self.raises(s_exc.AuthDeny):
                 await core.callStorm(wget, opts=opts)
 
+            # test wget runtsafe / per-node / per-node with cmdopt
+            nodes = await core.nodes(f'wget https://127.0.0.1:{port}/api/v1/active')
+            self.len(1, nodes)
+            self.eq(nodes[0].ndef[0], 'inet:urlfile')
+
+            nodes = await core.nodes(f'inet:url=https://127.0.0.1:{port}/api/v1/active | wget')
+            self.len(1, nodes)
+            self.eq(nodes[0].ndef[0], 'inet:urlfile')
+
+            nodes = await core.nodes(f'inet:urlfile:url=https://127.0.0.1:{port}/api/v1/active | wget :url')
+            self.len(1, nodes)
+            self.eq(nodes[0].ndef[0], 'inet:urlfile')
+
+            # check that the file name got set...
+            nodes = await core.nodes(f'wget https://127.0.0.1:{port}/api/v1/active | -> file:bytes +:name=active')
+            self.len(1, nodes)
+            self.eq(nodes[0].ndef[0], 'file:bytes')
+
+            msgs = await core.stormlist(f'wget https://127.0.0.1:{port}/api/v1/newp')
+            self.stormIsInWarn('HTTP code 404', msgs)
+
+            # test request timeout
+            async def timeout(self):
+                await asyncio.sleep(2)
+
+            with mock.patch.object(s_httpapi.ActiveV1, 'get', timeout):
+                msgs = await core.stormlist(f'wget https://127.0.0.1:{port}/api/v1/active --timeout 1')
+                self.stormIsInWarn('TimeoutError', msgs)
+
             await visi.addRule((True, ('storm', 'lib', 'axon', 'wget')))
             resp = await core.callStorm(wget, opts=opts)
             self.true(resp['ok'])
@@ -220,6 +250,8 @@ class StormTest(s_t_utils.SynTest):
             await core.addStormPkg(pkg0)
             self.eq('1.2.3', await core.callStorm('return($lib.pkg.get(hehe).version)'))
 
+            self.eq(None, await core.callStorm('return($lib.pkg.get(nopkg))'))
+
             # test for $lib.queue.gen()
             self.eq(0, await core.callStorm('return($lib.queue.gen(woot).size())'))
             # and again to test *not* creating it...
@@ -318,6 +350,13 @@ class StormTest(s_t_utils.SynTest):
             self.stormIsInPrint("aade791ea3263edd78e27d0351e7eed8372471a0434a6f0ba77101b5acf4f9bc inet:ipv4 DATA foo = 'bar'", msgs)
             self.stormIsInPrint('aade791ea3263edd78e27d0351e7eed8372471a0434a6f0ba77101b5acf4f9bc inet:ipv4 +(blahverb)> a0df14eab785847912993519f5606bbe741ad81afb51b81455ac6982a5686436', msgs)
 
+            msgs = await core.stormlist('ps:person | merge --diff', opts=opts)
+            self.stormIsInPrint('aade791ea3263edd78e27d0351e7eed8372471a0434a6f0ba77101b5acf4f9bc inet:ipv4:asn = 99', msgs)
+            self.stormIsInPrint("aade791ea3263edd78e27d0351e7eed8372471a0434a6f0ba77101b5acf4f9bc inet:ipv4#foo = ('2020/01/01 00:00:00.000', '2020/01/01 00:00:00.001')", msgs)
+            self.stormIsInPrint("aade791ea3263edd78e27d0351e7eed8372471a0434a6f0ba77101b5acf4f9bc inet:ipv4#foo:score = 100", msgs)
+            self.stormIsInPrint("aade791ea3263edd78e27d0351e7eed8372471a0434a6f0ba77101b5acf4f9bc inet:ipv4 DATA foo = 'bar'", msgs)
+            self.stormIsInPrint('aade791ea3263edd78e27d0351e7eed8372471a0434a6f0ba77101b5acf4f9bc inet:ipv4 +(blahverb)> a0df14eab785847912993519f5606bbe741ad81afb51b81455ac6982a5686436', msgs)
+
             await core.callStorm('inet:ipv4=11.22.33.44 | merge --apply', opts=opts)
             nodes = await core.nodes('inet:ipv4=11.22.33.44')
             self.len(1, nodes)
@@ -1679,10 +1718,18 @@ class StormTest(s_t_utils.SynTest):
                 self.len(1, [t for t in tasks if t.get('name').startswith('layer pull:')])
                 self.len(1, [t for t in tasks if t.get('name').startswith('layer push:')])
 
-                offs = await core.layers.get(layr2).getEditOffs()
                 await core.nodes('[ ps:contact=* ]', opts={'view': view0})
-                await core.layers.get(layr2).waitEditOffs(offs + 1, timeout=3)
-                self.len(1, await core.nodes('ps:contact', opts={'view': view2}))
+
+                # wait for first write so we can get the correct offset
+                await core.layers.get(layr2).waitEditOffs(0, timeout=3)
+                offs = await core.layers.get(layr2).getEditOffs()
+
+                await core.nodes('[ ps:contact=* ]', opts={'view': view0})
+                await core.nodes('[ ps:contact=* ]', opts={'view': view0})
+                await core.layers.get(layr2).waitEditOffs(offs + 10, timeout=3)
+
+                self.len(3, await core.nodes('ps:contact', opts={'view': view1}))
+                self.len(3, await core.nodes('ps:contact', opts={'view': view2}))
 
                 # remove and ensure no replay on restart
                 await core.nodes('ps:contact | delnode', opts={'view': view2})
@@ -1695,10 +1742,12 @@ class StormTest(s_t_utils.SynTest):
 
                 offs = await core.layers.get(layr2).getEditOffs()
                 await core.nodes('[ ps:contact=* ]', opts={'view': view0})
-                await core.layers.get(layr2).waitEditOffs(offs + 1, timeout=3)
+                await core.nodes('[ ps:contact=* ]', opts={'view': view0})
+                await core.nodes('[ ps:contact=* ]', opts={'view': view0})
+                await core.layers.get(layr2).waitEditOffs(offs + 6, timeout=3)
 
                 # confirm we dont replay and get the old one back...
-                self.len(1, await core.nodes('ps:contact', opts={'view': view2}))
+                self.len(3, await core.nodes('ps:contact', opts={'view': view2}))
 
                 actv = len(core.activecoros)
                 # remove all pushes / pulls
@@ -1745,7 +1794,7 @@ class StormTest(s_t_utils.SynTest):
 
                 # Wait for the active coros to die
                 for task in [t for t in tasks if t is not None]:
-                    await s_coro.waittask(task, timeout=5)
+                    self.true(await s_coro.waittask(task, timeout=5))
 
                 tasks = await core.callStorm('return($lib.ps.list())')
                 self.len(0, [t for t in tasks if t.get('name').startswith('layer pull:')])
