@@ -12,6 +12,7 @@ class OuModelTest(s_t_utils.SynTest):
             goal = s_common.guid()
             org0 = s_common.guid()
             camp = s_common.guid()
+            acto = s_common.guid()
 
             async with await core.snap() as snap:
 
@@ -41,6 +42,7 @@ class OuModelTest(s_t_utils.SynTest):
                     'org': org0,
                     'goal': goal,
                     'goals': (goal,),
+                    'actors': (acto,),
                     'name': 'MyName',
                     'type': 'MyType',
                     'desc': 'MyDesc',
@@ -49,6 +51,7 @@ class OuModelTest(s_t_utils.SynTest):
                 self.eq(node.get('org'), org0)
                 self.eq(node.get('goal'), goal)
                 self.eq(node.get('goals'), (goal,))
+                self.eq(node.get('actors'), (acto,))
                 self.eq(node.get('name'), 'MyName')
                 self.eq(node.get('type'), 'MyType')
                 self.eq(node.get('desc'), 'MyDesc')
@@ -135,6 +138,7 @@ class OuModelTest(s_t_utils.SynTest):
                     'loc': 'US.CA',
                     'name': name,
                     'names': altnames,
+                    'logo': '*',
                     'alias': 'arrow',
                     'phone': '+15555555555',
                     'sic': '0119',
@@ -158,6 +162,8 @@ class OuModelTest(s_t_utils.SynTest):
                 self.eq(node.get('founded'), 1420070400000)
                 self.eq(node.get('dissolved'), 1546300800000)
 
+                self.nn(node.get('logo'))
+
                 nodes = await snap.nodes('ou:name')
                 self.sorteq([x.ndef[1] for x in nodes], (normname,) + altnames)
 
@@ -375,6 +381,78 @@ class OuModelTest(s_t_utils.SynTest):
             self.len(2, await core.nodes('ou:org=$iden :locations -> ps:contact', opts=opts))
             self.len(2, await core.nodes('ou:org=$iden :dns:mx -> inet:fqdn', opts=opts))
 
+            nodes = await core.nodes('''[
+                ou:attendee=*
+                    :person=*
+                    :arrived=201202
+                    :departed=201203
+                    :meet=*
+                    :conference=*
+                    :conference:event=*
+                    :roles+=staff
+                    :roles+=STAFF
+            ]''')
+            self.len(1, nodes)
+            self.eq(('staff',), nodes[0].get('roles'))
+            self.eq(1328054400000, nodes[0].get('arrived'))
+            self.eq(1330560000000, nodes[0].get('departed'))
+
+            self.len(1, await core.nodes('ou:attendee -> ps:contact'))
+
+            self.len(1, await core.nodes('ou:attendee -> ou:meet'))
+            self.len(1, await core.nodes('ou:attendee -> ou:conference'))
+            self.len(1, await core.nodes('ou:attendee -> ou:conference:event'))
+
+            cont = s_common.guid()
+            nodes = await core.nodes(f'''[
+                ou:contest={cont}
+                    :name="defcon ctf 2020"
+                    :type="cyber ctf"
+                    :family="defcon ctf"
+                    :start=20200808
+                    :end=20200811
+
+                    :loc=us.nv.lasvegas
+                    :place=*
+                    :latlong=(20, 30)
+
+                    :conference=*
+                    :contests=(*,*)
+                    :sponsors=(*,)
+                    :organizers=(*,)
+                    :participants=(*,)
+
+            ]''')
+            self.len(1, nodes)
+            self.eq('defcon ctf 2020', nodes[0].get('name'))
+            self.eq('cyber ctf', nodes[0].get('type'))
+            self.eq('defcon ctf', nodes[0].get('family'))
+
+            self.eq(1596844800000, nodes[0].get('start'))
+            self.eq(1597104000000, nodes[0].get('end'))
+
+            self.eq((20, 30), nodes[0].get('latlong'))
+            self.eq('us.nv.lasvegas', nodes[0].get('loc'))
+
+            self.len(2, await core.nodes(f'ou:contest={cont} -> ou:contest'))
+            self.len(1, await core.nodes(f'ou:contest={cont} -> ou:conference'))
+            self.len(1, await core.nodes(f'ou:contest={cont} :sponsors -> ps:contact'))
+            self.len(1, await core.nodes(f'ou:contest={cont} :organizers -> ps:contact'))
+            self.len(1, await core.nodes(f'ou:contest={cont} :participants -> ps:contact'))
+
+            nodes = await core.nodes('''[
+                ou:contest:result=(*, *)
+                    :rank=1
+                    :score=20
+            ]''')
+            self.len(1, nodes)
+            self.nn(nodes[0].get('contest'))
+            self.nn(nodes[0].get('participant'))
+            self.eq(1, nodes[0].get('rank'))
+            self.eq(20, nodes[0].get('score'))
+            self.len(1, await core.nodes('ou:contest:result -> ps:contact'))
+            self.len(1, await core.nodes('ou:contest:result -> ou:contest'))
+
     async def test_ou_code_prefixes(self):
         guid0 = s_common.guid()
         guid1 = s_common.guid()
